==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/configdefs/errorsconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "errorsconfigwidget.h"
#include "errorsconfigdefs.h"

#include <qlayout.h>
#include <qgroupbox.h>
#include <qlabel.h>
#include <knuminput.h>
#include <timeedit.h>
#include <qcheckbox.h>

#include <klocale.h>

using namespace SubtitleComposer;

ErrorsConfigWidget::ErrorsConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QGroupBox* textsGroupBox = createGroupBox( i18n( "Texts" ) );

	QLabel* maxCharactersLabel = new QLabel( textsGroupBox );
	maxCharactersLabel->setText( i18n( "Maximum number of characters" ) );

	m_maxCharactersSpinBox = new KIntNumInput( textsGroupBox );
	m_maxCharactersSpinBox->setMinValue( 0 );
	m_maxCharactersSpinBox->setMaxValue( 200 );
	m_maxCharactersSpinBox->setSuffix( i18n( " characters" ) );

	QLabel* maxLinesLabel = new QLabel( textsGroupBox );
	maxLinesLabel->setText( i18n( "Maximum number of lines" ) );

	m_maxLinesSpinBox = new KIntNumInput( textsGroupBox );
	m_maxLinesSpinBox->setMinValue( 1 );
	m_maxLinesSpinBox->setMaxValue( 20 );
	m_maxLinesSpinBox->setSuffix( i18n( " lines" ) );


	QGroupBox* absoluteDurationsGroupBox = createGroupBox( i18n( "Absolute durations" ) );

	QLabel* minDurationLabel = new QLabel( absoluteDurationsGroupBox );
	minDurationLabel->setText( i18n( "Minimum duration" ) );

	m_minDurationTimeEdit = new KIntNumInput( absoluteDurationsGroupBox );
	m_minDurationTimeEdit->setMinValue( 0 );
	m_minDurationTimeEdit->setMaxValue( 2000 );
	m_minDurationTimeEdit->setSuffix( i18n( " msecs" ) );

	QLabel* maxDurationLabel = new QLabel( absoluteDurationsGroupBox );
	maxDurationLabel->setText( i18n( "Maximum duration" ) );

	m_maxDurationTimeEdit = new KIntNumInput( absoluteDurationsGroupBox );
	m_maxDurationTimeEdit->setMinValue( 2000 );
	m_maxDurationTimeEdit->setMaxValue( 8000 );
	m_maxDurationTimeEdit->setSuffix( i18n( " msecs" ) );


	QGroupBox* relativeDurationsGroupBox = createGroupBox( i18n( "Relative durations" ) );

	QLabel* minDurationPerCharLabel = new QLabel( relativeDurationsGroupBox );
	minDurationPerCharLabel->setText( i18n( "Minimum duration" ) );

	m_minDurationPerCharTimeEdit = new KIntNumInput( relativeDurationsGroupBox );
	m_minDurationPerCharTimeEdit->setMinValue( 0 );
	m_minDurationPerCharTimeEdit->setMaxValue( 100 );
	m_minDurationPerCharTimeEdit->setSuffix( i18n( " msecs/character" ) );

	QLabel* maxDurationPerCharLabel = new QLabel( relativeDurationsGroupBox );
	maxDurationPerCharLabel->setText( i18n( "Maximum duration" ) );

	m_maxDurationPerCharTimeEdit = new KIntNumInput( relativeDurationsGroupBox );
	m_maxDurationPerCharTimeEdit->setMinValue( 0 );
	m_maxDurationPerCharTimeEdit->setMaxValue( 500 );
	m_maxDurationPerCharTimeEdit->setSuffix( i18n( " msecs/character" ) );

	QGroupBox* behaviorGroupBox = createGroupBox( i18n( "Behavior" ) );

	m_autoClearFixedCheckBox = new QCheckBox( behaviorGroupBox );
	m_autoClearFixedCheckBox->setText( i18n( "Automatically clear fixed errors" ) );


	QGridLayout* textsLayout = createGridLayout( textsGroupBox );
	textsLayout->addWidget( maxCharactersLabel, 0, 0 );
	textsLayout->addWidget( m_maxCharactersSpinBox, 0, 1 );
	textsLayout->addWidget( maxLinesLabel, 1, 0 );
	textsLayout->addWidget( m_maxLinesSpinBox, 1, 1 );

	QGridLayout* absoluteDurationsLayout = createGridLayout( absoluteDurationsGroupBox );
	absoluteDurationsLayout->addWidget( minDurationLabel, 0, 0 );
	absoluteDurationsLayout->addWidget( m_minDurationTimeEdit, 0, 1 );
	absoluteDurationsLayout->addWidget( maxDurationLabel, 1, 0 );
	absoluteDurationsLayout->addWidget( m_maxDurationTimeEdit, 1, 1 );

	QGridLayout* relativeDurationsLayout = createGridLayout( relativeDurationsGroupBox );
	relativeDurationsLayout->addWidget( minDurationPerCharLabel, 0, 0 );
	relativeDurationsLayout->addWidget( m_minDurationPerCharTimeEdit, 0, 1 );
	relativeDurationsLayout->addWidget( maxDurationPerCharLabel, 1, 0 );
	relativeDurationsLayout->addWidget( m_maxDurationPerCharTimeEdit, 1, 1 );

	QGridLayout* behaviorLayout = createGridLayout( behaviorGroupBox );
	behaviorLayout->addWidget( m_autoClearFixedCheckBox, 0, 0 );

	connect( m_maxCharactersSpinBox, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxLinesSpinBox, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_minDurationTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxDurationTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_minDurationPerCharTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxDurationPerCharTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_autoClearFixedCheckBox, SIGNAL(toggled(bool)), this, SIGNAL(settingsChanged()) );

	setControlsFromConfig();
}

ErrorsConfigWidget::~ErrorsConfigWidget()
{
}

void ErrorsConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption( OPT_MAX_CHARACTERS, m_maxCharactersSpinBox->value() );
	m_configGroup.setOption( OPT_MAX_LINES, m_maxLinesSpinBox->value() );
	m_configGroup.setOption( OPT_MIN_DURATION, m_minDurationTimeEdit->value() );
	m_configGroup.setOption( OPT_MAX_DURATION, m_maxDurationTimeEdit->value() );
	m_configGroup.setOption( OPT_MIN_DURATION_PER_CHARACTER, m_minDurationPerCharTimeEdit->value() );
	m_configGroup.setOption( OPT_MAX_DURATION_PER_CHARACTER, m_maxDurationPerCharTimeEdit->value() );
	m_configGroup.setOption( OPT_AUTO_CLEAR_FIXED, m_autoClearFixedCheckBox->isChecked() );
}

void ErrorsConfigWidget::setControlsFromConfig()
{
	m_maxCharactersSpinBox->setValue( m_configGroup.optionAsInt( OPT_MAX_CHARACTERS ) );
	m_maxLinesSpinBox->setValue( m_configGroup.optionAsInt( OPT_MAX_LINES ) );
	m_minDurationTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MIN_DURATION ) );
	m_maxDurationTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MAX_DURATION ) );
	m_minDurationPerCharTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MIN_DURATION_PER_CHARACTER ) );
	m_maxDurationPerCharTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MAX_DURATION_PER_CHARACTER ) );
	m_autoClearFixedCheckBox->setChecked( m_configGroup.optionAsBool( OPT_AUTO_CLEAR_FIXED ) );
}

#include "errorsconfigwidget.moc"

==> subtitlecomposer-0.4.3.tar.bz2: subtitlecomposer-0.4.3/src/main/configdefs/errorsconfigwidget.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "errorsconfigwidget.h"
#include "errorsconfigdefs.h"

#include <qlayout.h>
#include <qbuttongroup.h>
#include <qlabel.h>
#include <knuminput.h>
#include <timeedit.h>
#include <qcheckbox.h>

#include <klocale.h>

using namespace SubtitleComposer;

ErrorsConfigWidget::ErrorsConfigWidget( const AppConfigGroup& configGroup, QWidget* parent ):
	AppConfigGroupWidget( configGroup, parent )
{
	QButtonGroup* textsButtonGroup = createButtonGroup( i18n( "Texts" ) );

	QLabel* maxCharactersLabel = new QLabel( textsButtonGroup );
	maxCharactersLabel->setText( i18n( "Maximum number of characters" ) );

	m_maxCharactersSpinBox = new KIntNumInput( textsButtonGroup );
	m_maxCharactersSpinBox->setMinValue( 0 );
	m_maxCharactersSpinBox->setMaxValue( 200 );
	m_maxCharactersSpinBox->setSuffix( i18n( " characters" ) );

	QLabel* maxLinesLabel = new QLabel( textsButtonGroup );
	maxLinesLabel->setText( i18n( "Maximum number of lines" ) );

	m_maxLinesSpinBox = new KIntNumInput( textsButtonGroup );
	m_maxLinesSpinBox->setMinValue( 1 );
	m_maxLinesSpinBox->setMaxValue( 20 );
	m_maxLinesSpinBox->setSuffix( i18n( " lines" ) );


	QButtonGroup* absoluteDurationsButtonGroup = createButtonGroup( i18n( "Absolute durations" ) );

	QLabel* minDurationLabel = new QLabel( absoluteDurationsButtonGroup );
	minDurationLabel->setText( i18n( "Minimum duration" ) );

	m_minDurationTimeEdit = new KIntNumInput( absoluteDurationsButtonGroup );
	m_minDurationTimeEdit->setMinValue( 0 );
	m_minDurationTimeEdit->setMaxValue( 2000 );
	m_minDurationTimeEdit->setSuffix( i18n( " msecs" ) );

	QLabel* maxDurationLabel = new QLabel( absoluteDurationsButtonGroup );
	maxDurationLabel->setText( i18n( "Maximum duration" ) );

	m_maxDurationTimeEdit = new KIntNumInput( absoluteDurationsButtonGroup );
	m_maxDurationTimeEdit->setMinValue( 2000 );
	m_maxDurationTimeEdit->setMaxValue( 8000 );
	m_maxDurationTimeEdit->setSuffix( i18n( " msecs" ) );


	QButtonGroup* relativeDurationsButtonGroup = createButtonGroup( i18n( "Relative durations" ) );

	QLabel* minDurationPerCharLabel = new QLabel( relativeDurationsButtonGroup );
	minDurationPerCharLabel->setText( i18n( "Minimum duration" ) );

	m_minDurationPerCharTimeEdit = new KIntNumInput( relativeDurationsButtonGroup );
	m_minDurationPerCharTimeEdit->setMinValue( 0 );
	m_minDurationPerCharTimeEdit->setMaxValue( 100 );
	m_minDurationPerCharTimeEdit->setSuffix( i18n( " msecs/character" ) );

	QLabel* maxDurationPerCharLabel = new QLabel( relativeDurationsButtonGroup );
	maxDurationPerCharLabel->setText( i18n( "Maximum duration" ) );

	m_maxDurationPerCharTimeEdit = new KIntNumInput( relativeDurationsButtonGroup );
	m_maxDurationPerCharTimeEdit->setMinValue( 0 );
	m_maxDurationPerCharTimeEdit->setMaxValue( 500 );
	m_maxDurationPerCharTimeEdit->setSuffix( i18n( " msecs/character" ) );


	QButtonGroup* behaviorButtonGroup = createButtonGroup( i18n( "Behavior" ) );

	m_autoClearFixedCheckBox = new QCheckBox( behaviorButtonGroup );
	m_autoClearFixedCheckBox->setText( i18n( "Automatically clear fixed errors" ) );


	QGridLayout* textsLayout = createGridLayout( textsButtonGroup );
	textsLayout->addWidget( maxCharactersLabel, 0, 0 );
	textsLayout->addWidget( m_maxCharactersSpinBox, 0, 1 );
	textsLayout->addWidget( maxLinesLabel, 1, 0 );
	textsLayout->addWidget( m_maxLinesSpinBox, 1, 1 );

	QGridLayout* absoluteDurationsLayout = createGridLayout( absoluteDurationsButtonGroup );
	absoluteDurationsLayout->addWidget( minDurationLabel, 0, 0 );
	absoluteDurationsLayout->addWidget( m_minDurationTimeEdit, 0, 1 );
	absoluteDurationsLayout->addWidget( maxDurationLabel, 1, 0 );
	absoluteDurationsLayout->addWidget( m_maxDurationTimeEdit, 1, 1 );

	QGridLayout* relativeDurationsLayout = createGridLayout( relativeDurationsButtonGroup );
	relativeDurationsLayout->addWidget( minDurationPerCharLabel, 0, 0 );
	relativeDurationsLayout->addWidget( m_minDurationPerCharTimeEdit, 0, 1 );
	relativeDurationsLayout->addWidget( maxDurationPerCharLabel, 1, 0 );
	relativeDurationsLayout->addWidget( m_maxDurationPerCharTimeEdit, 1, 1 );

	QGridLayout* behaviorLayout = createGridLayout( behaviorButtonGroup );
	behaviorLayout->addWidget( m_autoClearFixedCheckBox, 0, 0 );

	connect( m_maxCharactersSpinBox, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxLinesSpinBox, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_minDurationTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxDurationTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_minDurationPerCharTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_maxDurationPerCharTimeEdit, SIGNAL(valueChanged(int)), this, SIGNAL(settingsChanged()) );
	connect( m_autoClearFixedCheckBox, SIGNAL(toggled(bool)), this, SIGNAL(settingsChanged()) );

	setControlsFromConfig();
}

ErrorsConfigWidget::~ErrorsConfigWidget()
{
}

void ErrorsConfigWidget::setConfigFromControls()
{
	m_configGroup.setOption( OPT_MAX_CHARACTERS, m_maxCharactersSpinBox->value() );
	m_configGroup.setOption( OPT_MAX_LINES, m_maxLinesSpinBox->value() );
	m_configGroup.setOption( OPT_MIN_DURATION, m_minDurationTimeEdit->value() );
	m_configGroup.setOption( OPT_MAX_DURATION, m_maxDurationTimeEdit->value() );
	m_configGroup.setOption( OPT_MIN_DURATION_PER_CHARACTER, m_minDurationPerCharTimeEdit->value() );
	m_configGroup.setOption( OPT_MAX_DURATION_PER_CHARACTER, m_maxDurationPerCharTimeEdit->value() );
	m_configGroup.setOption( OPT_AUTO_CLEAR_FIXED, m_autoClearFixedCheckBox->isChecked() );
}

void ErrorsConfigWidget::setControlsFromConfig()
{
	m_maxCharactersSpinBox->setValue( m_configGroup.optionAsInt( OPT_MAX_CHARACTERS ) );
	m_maxLinesSpinBox->setValue( m_configGroup.optionAsInt( OPT_MAX_LINES ) );
	m_minDurationTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MIN_DURATION ) );
	m_maxDurationTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MAX_DURATION ) );
	m_minDurationPerCharTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MIN_DURATION_PER_CHARACTER ) );
	m_maxDurationPerCharTimeEdit->setValue( m_configGroup.optionAsInt( OPT_MAX_DURATION_PER_CHARACTER ) );
	m_autoClearFixedCheckBox->setChecked( m_configGroup.optionAsBool( OPT_AUTO_CLEAR_FIXED ) );
}

#include "errorsconfigwidget.moc"
